Welcome to cronomaxrf
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Recently my lab, the Rijkserfgoedlaboratorium in Amsterdam, acquired a
new Bruker Crono X-Ray Fluorescence spectral image (MACRO-XRF) scanner.
This instrument saves its raw data into a specific type of HDF5 file
format. Currently these files can only be read and converted by
commercially licensed Crono software. This situation restricts access to
the data to a limited number of researchers who can run the software.
Furthermore, it is likely that we will loose the ability to read the
data at some point in the future.

In order to make optimal use of the Crono data in collaborative research
projects now and to make sure that we can still read the data in the
future we need to: 1) understand the Crono HDF5 file format, and 2)
develop open software tools available to all researchers for reading and
converting these data files. To support open heritage science
`cronomaxrf` package is currently being developed under the GPLv3 open
source software license.

For installation instructions, documentation and code see:
https://fligt.github.io/cronomaxrf/
